changeset 9d5c5039fce0 in /home/hg/repos/gajim

details:http://hg.gajim.org/gajim?cmd=changeset;node=9d5c5039fce0
description: Whiteboard plugin. set tooltip for whiteboard button

diffstat:

 plugins/whiteboard/plugin.py |  5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)

diffs (24 lines):

diff -r 74e80c95422f -r 9d5c5039fce0 plugins/whiteboard/plugin.py
--- a/plugins/whiteboard/plugin.py      Sat Sep 03 10:40:35 2011 +0300
+++ b/plugins/whiteboard/plugin.py      Sat Sep 03 11:56:14 2011 +0300
@@ -120,8 +120,11 @@
                 if control.contact.supports(NS_JINGLE_SXE) and \
                 control.contact.supports(NS_SXE):
                     base.button.set_sensitive(True)
+                    base.button.set_tooltip_text(_('Show whiteboard'))
                 else:
                     base.button.set_sensitive(False)
+                    base.button.set_tooltip_text(_('Client on the other side '
+                        'does not support the whiteboard'))
 
     @log_calls('WhiteboardPlugin')
     def show_request_dialog(self, account, fjid, jid, sid, content_types):
@@ -267,7 +270,7 @@
         self.sid = None
 
     def create_buttons(self):
         # create juick button
         actions_hbox = self.chat_control.xml.get_object('actions_hbox')
         self.button = gtk.ToggleButton(label=None, use_underline=True)
         self.button.set_property('relief', gtk.RELIEF_NONE)
@@ -267,7 +270,7 @@
 
     def create_buttons(self):
-        # create juick button
+        # create whiteboard button
         actions_hbox = self.chat_control.xml.get_object('actions_hbox')
         self.button = gtk.ToggleButton(label=None, use_underline=True)
_______________________________________________
Commits mailing list
[email protected]
http://lists.gajim.org/cgi-bin/listinfo/commits

Reply via email to